#include <stdlib.h>

#include "level_menu.h"

#ifndef DEBUG
#include <curses.h>
#else
#include "movelist.h"
#endif

#include "play_xor.h"
#include "options.h"
#include "scores.h"
#include "screen.h"

int
main(void)
{
    int ret = 0;
    /* options need to be created first, as screen_create requires them. */
    if (!options_create()) {
        fprintf(stderr,
                "Please either install XorCurses by running "
                "'sudo make install' within the\n"
                "XorCurses-0.0.6 source directory, or always "
                "start XorCurses from within that\ndirectory.\n");
        ret = 1;
        goto bail;
    }
    if (!screen_create()) {
        ret = 1;
        goto bail;
    }
    if (!screen_size()) {
        fprintf(stderr,
                "Terminal too small!\nPlease resize and try again,\nif possible.\n");
        ret = 1;
        goto bail;
    }
    if (!options_create_map_names()) {
        fprintf(stderr,
                "A problem occurred establishing the map names, sorry :-(\n");
        ret = 1;
        goto bail;
    }
    create_scores();
    load_scores();
#ifndef DEBUG
    init_icons();
    lvl_t lastlevel;
    lvl_t level = 1;
    do {
        lastlevel = level;
        level = level_menu(level);
        switch (level) {
        case 100:
            if ((level = replay_load()) < 0)
                level = lastlevel;
            else if (level == 100) {
                while (play_xor(level, FALSE));
                level = replay.level;
                level = replay.level;
            }
            wclear(info_win);
            wrefresh(info_win);
            break;
        case 999:
            level = lastlevel;
            help();
            break;
        default:
            if (level >= 0 && level <= 15) {
                if (play_xor(level, TRUE)) {
                    while (play_xor(level, FALSE));
                    level = replay.level;
                }
                wclear(info_win);
                wrefresh(info_win);
            }
        }
    } while (level >= 0);
#else
    printf("struct sizes:\n\txor_move %ld\n\txmv_link %ld\n\txmv_list %ld\n",
           sizeof(struct xor_move), sizeof(struct xmv_link),
           sizeof(struct xmv_list));
    do {
        if ((level = level_menu(level)) >= 0) {
            play_xor(level, TRUE);
        }
    } while (level >= 0);
#endif

  bail:
    screen_destroy();
    destroy_scores();
    options_destroy_map_names();
    options_destroy();
    return ret;
}
